Credential Providers
--------------------

.. autosummary::

   ~coredis.credentials.AbstractCredentialProvider
   ~coredis.credentials.UserPassCredentialProvider
   ~coredis.credentials.UserPass


.. autoclass:: coredis.credentials.AbstractCredentialProvider
   :class-doc-from: both

.. autoclass:: coredis.credentials.UserPassCredentialProvider
   :class-doc-from: both

.. autoclass:: coredis.credentials.UserPass
   :no-inherited-members:


.. autoclass:: coredis.recipes.credentials.ElastiCacheIAMProvider
   :class-doc-from: both